==> jscommunicator-1.0.21.tgz: package/src/communicatorClient.js <==
"use strict"

let genericTransactionalMail = require('./genericTransactionalMail');
let genericPromotionalMail = require('./genericPromotionalMail');
let genericTransactionalSms = require('./genericTransactionalSms');
let genericPromotionalSms = require('./genericPromotionalSms');
let otpSms = require('./otpSms');
let patientPromoAndroidPush = require('./patientPromoAndroidPush');
let patientTransAndroidPush = require('./patientTransAndroidPush');
let patientPromoIosPush = require('./patientPromoIosPush');
let patientTransIosPush = require('./patientTransIosPush');


class CommunicatorClient{
  constructor(host, config, appName){
    this.host = host;
    this.config = config;
    this.appName = appName;
  }

  getInstance(serviceType){
    if(serviceType === "mailGenericTransactional"){
      return new genericTransactionalMail.MailGenericTransactional(
        this.host, this.config, this.appName);
    }
    else if(serviceType === "smsGenericTransactional"){
      return new genericTransactionalSms.SmsGenericTransactional(
        this.host, this.config, this.appName);
    }
    else if(serviceType === "mailGenericPromotional"){
      return new genericPromotionalMail.MailGenericPromotional(
        this.host, this.config, this.appName);
    }
    else if(serviceType === "smsGenericPromotional"){
      return new genericPromotionalSms.SmsGenericPromotional(
        this.host, this.config, this.appName);
    }
    else if(serviceType === "smsOtp"){
      return new otpSms.OtpSms(
        this.host, this.config, this.appName);
    } else if (serviceType === "patientPromoAndroidPush") {
      return new patientPromoAndroidPush.PatientPromoAndroidPush(
        this.host, this.config, this.appName);
    } else if (serviceType === "patientTransAndroidPush") {
      return new patientTransAndroidPush.PatientTransAndroidPush(
        this.host, this.config, this.appName);
    } else if (serviceType === "patientPromoIosPush") {
      return new patientPromoIosPush.PatientPromoIosPush(
        this.host, this.config, this.appName);
    } else if (serviceType === "patientTransIosPush") {
      return new patientTransIosPush.PatientTransIosPush(
        this.host, this.config, this.appName);
    }
    else{
      throw "unknown service type";
    }
  }
}

module.exports = {
  CommunicatorClient: CommunicatorClient
}

==> jscommunicator-1.0.27.tgz: package/src/communicatorClient.js <==
"use strict"

let genericTransactionalMail = require('./genericTransactionalMail');
let genericPromotionalMail = require('./genericPromotionalMail');
let genericTransactionalSms = require('./genericTransactionalSms');
let genericPromotionalSms = require('./genericPromotionalSms');
let otpSms = require('./otpSms');
let patientPromoAndroidPush = require('./patientPromoAndroidPush');
let patientTransAndroidPush = require('./patientTransAndroidPush');
let patientPromoIosPush = require('./patientPromoIosPush');
let patientTransIosPush = require('./patientTransIosPush');


class CommunicatorClient{
  constructor(request, config, appName){
    console.log("-----------REQUEST --------------");
    console.log(request.headers);
    this.request = request;
    this.config = config;
    this.appName = appName;
  }

  getInstance(serviceType){
    if(serviceType === "mailGenericTransactional"){
      return new genericTransactionalMail.MailGenericTransactional(
        this.request, this.config, this.appName);
    }
    else if(serviceType === "smsGenericTransactional"){
      return new genericTransactionalSms.SmsGenericTransactional(
        this.request, this.config, this.appName);
    }
    else if(serviceType === "mailGenericPromotional"){
      return new genericPromotionalMail.MailGenericPromotional(
        this.request, this.config, this.appName);
    }
    else if(serviceType === "smsGenericPromotional"){
      return new genericPromotionalSms.SmsGenericPromotional(
        this.request, this.config, this.appName);
    }
    else if(serviceType === "smsOtp"){
      return new otpSms.OtpSms(
        this.request, this.config, this.appName);
    } else if (serviceType === "patientPromoAndroidPush") {
      return new patientPromoAndroidPush.PatientPromoAndroidPush(
        this.request, this.config, this.appName);
    } else if (serviceType === "patientTransAndroidPush") {
      return new patientTransAndroidPush.PatientTransAndroidPush(
        this.request, this.config, this.appName);
    } else if (serviceType === "patientPromoIosPush") {
      return new patientPromoIosPush.PatientPromoIosPush(
        this.request, this.config, this.appName);
    } else if (serviceType === "patientTransIosPush") {
      return new patientTransIosPush.PatientTransIosPush(
        this.request, this.config, this.appName);
    }
    else{
      throw "unknown service type";
    }
  }
}

module.exports = {
  CommunicatorClient: CommunicatorClient
}
